/*
 * FragmentationChargeDensity.hpp
 *
 *  Created on: Aug 31, 2012
 *      Author: heber
 */

#ifndef FRAGMENTATIONCHARGEDENSITY_HPP_
#define FRAGMENTATIONCHARGEDENSITY_HPP_


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <map>
#include <string>
#include <vector>

#include "JobMarket/types.hpp"

#include "Fragmentation/SetValues/Fragment.hpp"
#include "Fragmentation/Summation/IndexSet.hpp"
#include "Jobs/MPQCData.hpp"
#include "Jobs/MPQCDataMap.hpp"
#include "Jobs/Grid/SamplingGrid.hpp"

/** This structure is a container for the summed up charge density per level.
 *
 */
struct FragmentationChargeDensity
{
  /** Sums up sampled charge grids contained in \a fragmentData.
   *
   * @param fragmentData MPQCData resulting from the jobs, each associated to a job
   * @param KeySetFilename filename with keysets to associate forces correctly
   */
  FragmentationChargeDensity(
      const std::map<JobId_t,MPQCData> &fragmentData,
      const std::string &KeySetFilename);

  std::vector<SamplingGrid> getFullSampledGrid();

  const Fragment &getFragment();

  //!> results per level of summed up sampled grid charge
  std::vector<MPQCDataGridMap_t> Result_Grid_fused;
  //!> results per level of summed up fragment positions and charges
  std::vector<MPQCDataFragmentMap_t> Result_Fragment_fused;

  //!> results per IndexSet of summed up sampled grid charge
  std::map<IndexSet::ptr, MPQCDataGridMap_t> Result_perIndexSet_Grid;
  //!> results per IndexSet of summed up fragment positions and charges
  std::map<IndexSet::ptr, MPQCDataFragmentMap_t> Result_perIndexSet_Fragment;
};

#endif /* FRAGMENTATIONCHARGEDENSITY_HPP_ */
